/*
   Copyright 2012 Wolfgang Koller - http://www.gofg.at/

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

cordova.define("cordova/plugin/bluetooth", function(require, exports, module) {
	var exec = require('cordova/exec');
	
	var Bluetooth = function() {};
	
	/**
	 * Check if bluetooth API is supported on this platform
	 * @returns true if bluetooth API is supported, false otherwise
	 */
	Bluetooth.prototype.isSupported = function() {
		// Currently only supported on android
		if( device.platform.toLowerCase() == "android" ) return true;
		
		return false;
	}
	
	/**
	 * Enable bluetooth
	 * 
	 * @param successCallback function to be called when enabling of bluetooth was successfull
	 * @param errorCallback function to be called when enabling was not possible / did fail
	 */
	Bluetooth.prototype.enable = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'enable', []);
	}
	
	/**
	 * Disable bluetooth
	 * 
	 * @param successCallback function to be called when disabling of bluetooth was successfull
	 * @param errorCallback function to be called when disabling was not possible / did fail
	 */
	Bluetooth.prototype.disable = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'disable', []);
	}
	
	/**
	 * Search for devices  and list them
	 * 
	 * @param successCallback function to be called when discovery of other devices has finished. Passed parameter is a JSONArray containing JSONObjects with 'name' and 'address' property.
	 * @param errorCallback function to be called when there was a problem while discovering devices
	 */
	Bluetooth.prototype.discoverDevices = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'discoverDevices', []);
	}
	
	/**
	 * Return list of available UUIDs for a given device
	 * 
	 * @param successCallback function to be called when listing of UUIDs has finished. Passed parameter is a JSONArray containing strings which represent the UUIDs
	 * @param errorCallback function to be called when there was a problem while listing UUIDs
	 */
	Bluetooth.prototype.getUUIDs = function(successCallback,failureCallback,address) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'getUUIDs', [address]);
	}
	
	/**
	 * Open an RFComm channel for a given device & uuid endpoint
	 * 
	 * @param successCallback function to be called when the connection was successfull. Passed parameter is an integer containing the socket id for the connection
	 * @param errorCallback function to be called when there was a problem while opening the connection
	 */
	Bluetooth.prototype.connect = function(successCallback,failureCallback,address,uuid) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'connect', [address, uuid]);
	}
	
	/**
	 * Close a RFComm channel for a given socket-id
	 * 
	 * @param successCallback function to be called when the connection was closed successfully
	 * @param errorCallback function to be called when there was a problem while closing the connection
	 */
	Bluetooth.prototype.disconnect = function(successCallback,failureCallback,socketid) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'disconnect', [socketid]);
	}
	
	/**
	 * Read from a connected socket
	 * 
	 * @param successCallback function to be called when reading was successfull. Passed parameter is a string containing the read content
	 * @param errorCallback function to be called when there was a problem while reading
	 */
	Bluetooth.prototype.read = function(successCallback,failureCallback,socketid) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'read', [socketid]);
	}
	Bluetooth.prototype.readhex = function(successCallback,failureCallback,socketid) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'readhex', [socketid]);
	}
	Bluetooth.prototype.readnow = function(successCallback,failureCallback,address,uuid) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'readnow', [address, uuid]);
	}
	
	/**
	 * Read from a connected socket
	 * 
	 * @param successCallback function to be called when reading was successfull. Passed parameter is a string containing the read content
	 * @param errorCallback function to be called when there was a problem while reading
	 */
	Bluetooth.prototype.write = function(successCallback,failureCallback,socketid,txt) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'write', [socketid, txt]);
	}
	Bluetooth.prototype.writenow = function(successCallback,failureCallback,address,uuid,txt) {
	    return exec(successCallback, failureCallback, 'BluetoothPlugin', 'writenow', [address, uuid, txt]);
	}
	
	var bluetooth = new Bluetooth();
	module.exports = bluetooth;
});

cordova.define("cordova/plugin/bluetooth4", function(require, exports, module) {
	var exec = require('cordova/exec');
	
	var Bluetooth4 = function() {};
	
	/**
	 * Check if bluetooth API is supported on this platform
	 * @returns true if bluetooth API is supported, false otherwise
	 */
	Bluetooth4.prototype.isSupported = function() {
		// Currently only supported on android
		if( device.platform.toLowerCase() == "android" ) return true;
		
		return false;
	}
	
	Bluetooth4.prototype.ping = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'Bluetooth4Plugin', 'ping', []);
	}
	
	/**
	 * Enable bluetooth
	 * 
	 * @param successCallback function to be called when enabling of bluetooth was successfull
	 * @param errorCallback function to be called when enabling was not possible / did fail
	 */
	Bluetooth4.prototype.enable = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'Bluetooth4Plugin', 'enable', []);
	}
	
	/**
	 * Disable bluetooth
	 * 
	 * @param successCallback function to be called when disabling of bluetooth was successfull
	 * @param errorCallback function to be called when disabling was not possible / did fail
	 */
	Bluetooth4.prototype.disable = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'Bluetooth4Plugin', 'disable', []);
	}
	
	/**
	 * Search for devices  and list them
	 * 
	 * @param successCallback function to be called when discovery of other devices has finished. Passed parameter is a JSONArray containing JSONObjects with 'name' and 'address' property.
	 * @param errorCallback function to be called when there was a problem while discovering devices
	 */
	Bluetooth4.prototype.discoverDevices = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'Bluetooth4Plugin', 'discoverDevices', []);
	}
	
	/**
	 * Open an RFComm channel for a given device & uuid endpoint
	 * 
	 * @param successCallback function to be called when the connection was successfull. Passed parameter is an integer containing the socket id for the connection
	 * @param errorCallback function to be called when there was a problem while opening the connection
	 */
	Bluetooth4.prototype.connect = function(successCallback,failureCallback,address) {
	    return exec(successCallback, failureCallback, 'Bluetooth4Plugin', 'connect', [address]);
	}
	
	/**
	 * Close a RFComm channel for a given socket-id
	 * 
	 * @param successCallback function to be called when the connection was closed successfully
	 * @param errorCallback function to be called when there was a problem while closing the connection
	 */
	Bluetooth4.prototype.disconnect = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'Bluetooth4Plugin', 'disconnect', []);
	}
	
	/**
	 * Read from a connected socket
	 * 
	 * @param successCallback function to be called when reading was successfull. Passed parameter is a string containing the read content
	 * @param errorCallback function to be called when there was a problem while reading
	 */
	Bluetooth4.prototype.read = function(successCallback,failureCallback,address) {
	    return exec(successCallback, failureCallback, 'Bluetooth4Plugin', 'read', [address]);
	}
	
	var bluetooth4 = new Bluetooth4();
	module.exports = bluetooth4;
});

cordova.define("cordova/plugin/bluetoothle", function(require, exports, module) {
	var exec = require('cordova/exec');
	
	var BluetoothLE = function() {};
	
	/**
	 * Check if bluetooth API is supported on this platform
	 * @returns true if bluetooth API is supported, false otherwise
	 */
	BluetoothLE.prototype.isSupported = function() {
		// Currently only supported on android
		if( device.platform.toLowerCase() == "android" ) return true;
		
		return false;
	}
	
	BluetoothLE.prototype.ping = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'BluetoothLEPlugin', 'ping', []);
	}
	
	/**
	 * Enable bluetooth
	 * 
	 * @param successCallback function to be called when enabling of bluetooth was successfull
	 * @param errorCallback function to be called when enabling was not possible / did fail
	 */
	BluetoothLE.prototype.enable = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'BluetoothLEPlugin', 'enable', []);
	}
	
	/**
	 * Disable bluetooth
	 * 
	 * @param successCallback function to be called when disabling of bluetooth was successfull
	 * @param errorCallback function to be called when disabling was not possible / did fail
	 */
	BluetoothLE.prototype.disable = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'BluetoothLEPlugin', 'disable', []);
	}
	
	/**
	 * Search for devices  and list them
	 * 
	 * @param successCallback function to be called when discovery of other devices has finished. Passed parameter is a JSONArray containing JSONObjects with 'name' and 'address' property.
	 * @param errorCallback function to be called when there was a problem while discovering devices
	 */
	BluetoothLE.prototype.discoverDevices = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'BluetoothLEPlugin', 'discoverDevices', []);
	}
	
	/**
	 * Open an RFComm channel for a given device & uuid endpoint
	 * 
	 * @param successCallback function to be called when the connection was successfull. Passed parameter is an integer containing the socket id for the connection
	 * @param errorCallback function to be called when there was a problem while opening the connection
	 */
	BluetoothLE.prototype.connect = function(successCallback,failureCallback,address) {
	    return exec(successCallback, failureCallback, 'BluetoothLEPlugin', 'connect', [address]);
	}
	
	/**
	 * Close a RFComm channel for a given socket-id
	 * 
	 * @param successCallback function to be called when the connection was closed successfully
	 * @param errorCallback function to be called when there was a problem while closing the connection
	 */
	BluetoothLE.prototype.disconnect = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'BluetoothLEPlugin', 'disconnect', []);
	}
	
	/**
	 * Read from a connected socket
	 * 
	 * @param successCallback function to be called when reading was successfull. Passed parameter is a string containing the read content
	 * @param errorCallback function to be called when there was a problem while reading
	 */
	BluetoothLE.prototype.read = function(successCallback,failureCallback,address) {
	    return exec(successCallback, failureCallback, 'BluetoothLEPlugin', 'read', [address]);
	}
	
	var bluetoothle = new BluetoothLE();
	module.exports = bluetoothle;
});

cordova.define("cordova/plugin/filesystem", function(require, exports, module) {
	var exec = require('cordova/exec');
	
	var Filesystem = function() {};
	
	/**
	 * Check if bluetooth API is supported on this platform
	 * @returns true if bluetooth API is supported, false otherwise
	 */
	Filesystem.prototype.isSupported = function() {
		// Currently only supported on android
		if( device.platform.toLowerCase() == "android" ) return true;
		
		return false;
	}
	
	Filesystem.prototype.filedirectory = function(successCallback,failureCallback) {
	    return exec(successCallback, failureCallback, 'FilesystemPlugin', 'filedirectory', []);
	}
	Filesystem.prototype.fileread = function(successCallback,failureCallback,filename) {
	    return exec(successCallback, failureCallback, 'FilesystemPlugin', 'fileread', [filename]);
	}
	Filesystem.prototype.filewrite = function(successCallback,failureCallback,filename,filedata) {
	    return exec(successCallback, failureCallback, 'FilesystemPlugin', 'filewrite', [filename,filedata]);
	}
	Filesystem.prototype.fileappend = function(successCallback,failureCallback,filename,filedata) {
	    return exec(successCallback, failureCallback, 'FilesystemPlugin', 'fileappend', [filename,filedata]);
	}
	Filesystem.prototype.filedelete = function(successCallback,failureCallback,filename) {
	    return exec(successCallback, failureCallback, 'FilesystemPlugin', 'filedelete', [filename]);
	}
	
	var filesystem = new Filesystem();
	module.exports = filesystem;
});
